@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtwidgets_python.h>
 #include <pyside2_qtgui_python.h>
@@ -59,92 +53,97 @@
 
 // Binded library includes
 #include <qhelpcontentwidget.h>
-#include <qhelpsearchengine.h>
 #include <qhelpenginecore.h>
+#include <qhelpsearchengine.h>
 #include <qhelpsearchquerywidget.h>
 #include <qhelpindexwidget.h>
 #include <qhelpengine.h>
 #include <qhelpsearchresultwidget.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QHELPSEARCHRESULT_IDX                                    11
-#define SBK_QHELPSEARCHQUERY_IDX                                     8
-#define SBK_QHELPSEARCHQUERY_FIELDNAME_IDX                           9
-#define SBK_QHELPCONTENTITEM_IDX                                     0
-#define SBK_QHELPCONTENTMODEL_IDX                                    1
-#define SBK_QHELPINDEXMODEL_IDX                                      5
-#define SBK_QHELPSEARCHENGINE_IDX                                    7
-#define SBK_QHELPENGINECORE_IDX                                      4
-#define SBK_QHELPENGINE_IDX                                          3
-#define SBK_QHELPSEARCHRESULTWIDGET_IDX                              12
-#define SBK_QHELPSEARCHQUERYWIDGET_IDX                               10
-#define SBK_QHELPINDEXWIDGET_IDX                                     6
-#define SBK_QHELPCONTENTWIDGET_IDX                                   2
-#define SBK_QtHelp_IDX_COUNT                                         13
-
+enum : int {
+    SBK_QHELPCONTENTITEM_IDX                                 = 0,
+    SBK_QHELPCONTENTMODEL_IDX                                = 1,
+    SBK_QHELPCONTENTWIDGET_IDX                               = 2,
+    SBK_QHELPENGINE_IDX                                      = 3,
+    SBK_QHELPENGINECORE_IDX                                  = 4,
+    SBK_QHELPINDEXMODEL_IDX                                  = 5,
+    SBK_QHELPINDEXWIDGET_IDX                                 = 6,
+    SBK_QHELPSEARCHENGINE_IDX                                = 7,
+    SBK_QHELPSEARCHQUERY_IDX                                 = 8,
+    SBK_QHELPSEARCHQUERY_FIELDNAME_IDX                       = 9,
+    SBK_QHELPSEARCHQUERYWIDGET_IDX                           = 10,
+    SBK_QHELPSEARCHRESULT_IDX                                = 11,
+    SBK_QHELPSEARCHRESULTWIDGET_IDX                          = 12,
+    SBK_QtHelp_IDX_COUNT                                     = 13
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtHelpTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtHelpModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtHelpTypeConverters;
 
 // Converter indices
-#define SBK_QTHELP_QLIST_QOBJECTPTR_IDX                              0 // const QList<QObject* > &
-#define SBK_QTHELP_QVECTOR_INT_IDX                                   1 // const QVector<int > &
-#define SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                          2 // const QHash<int,QByteArray > &
-#define SBK_QTHELP_QLIST_QBYTEARRAY_IDX                              3 // QList<QByteArray >
-#define SBK_QTHELP_QMAP_INT_QVARIANT_IDX                             4 // QMap<int,QVariant >
-#define SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX                   5 // const QList<QPersistentModelIndex > &
-#define SBK_QTHELP_QMAP_QSTRING_QURL_IDX                             6 // QMap<QString,QUrl >
-#define SBK_QTHELP_QPAIR_QSTRING_QSTRING_IDX                         7 // QPair<QString,QString >
-#define SBK_QTHELP_QLIST_QPAIR_QSTRING_QSTRING_IDX                   8 // QList<QPair< QString,QString > >
-#define SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                        9 // QList<QHelpSearchQuery >
-#define SBK_QTHELP_QVECTOR_QHELPSEARCHRESULT_IDX                     10 // QVector<QHelpSearchResult >
-#define SBK_QTHELP_QLIST_QURL_IDX                                    11 // QList<QUrl >
-#define SBK_QTHELP_QLIST_QSTRINGLIST_IDX                             12 // QList<QStringList >
-#define SBK_QTHELP_QLIST_QACTIONPTR_IDX                              13 // QList<QAction* >
-#define SBK_QTHELP_QLIST_QWIDGETPTR_IDX                              14 // QList<QWidget* >
-#define SBK_QTHELP_QLIST_QVARIANT_IDX                                15 // QList<QVariant >
-#define SBK_QTHELP_QLIST_QSTRING_IDX                                 16 // QList<QString >
-#define SBK_QTHELP_QMAP_QSTRING_QVARIANT_IDX                         17 // QMap<QString,QVariant >
-#define SBK_QtHelp_CONVERTERS_IDX_COUNT                              18
-
+enum : int {
+    SBK_QTHELP_QLIST_QOBJECTPTR_IDX                          = 0, // const QList<QObject* > &
+    SBK_QTHELP_QVECTOR_INT_IDX                               = 1, // const QVector<int > &
+    SBK_QTHELP_QHASH_INT_QBYTEARRAY_IDX                      = 2, // const QHash<int,QByteArray > &
+    SBK_QTHELP_QLIST_QBYTEARRAY_IDX                          = 3, // QList<QByteArray >
+    SBK_QTHELP_QMAP_INT_QVARIANT_IDX                         = 4, // QMap<int,QVariant >
+    SBK_QTHELP_QLIST_QPERSISTENTMODELINDEX_IDX               = 5, // const QList<QPersistentModelIndex > &
+    SBK_QTHELP_QLIST_QACTIONPTR_IDX                          = 6, // QList<QAction* >
+    SBK_QTHELP_QLIST_QWIDGETPTR_IDX                          = 7, // QList<QWidget* >
+    SBK_QTHELP_QLIST_QURL_IDX                                = 8, // QList<QUrl >
+    SBK_QTHELP_QLIST_QSTRINGLIST_IDX                         = 9, // QList<QStringList >
+    SBK_QTHELP_QMAP_QSTRING_QURL_IDX                         = 10, // QMap<QString,QUrl >
+    SBK_QTHELP_QPAIR_QSTRING_QSTRING_IDX                     = 11, // QPair<QString,QString >
+    SBK_QTHELP_QLIST_QPAIR_QSTRING_QSTRING_IDX               = 12, // QList<QPair< QString,QString > >
+    SBK_QTHELP_QLIST_QHELPSEARCHQUERY_IDX                    = 13, // QList<QHelpSearchQuery >
+    SBK_QTHELP_QVECTOR_QHELPSEARCHRESULT_IDX                 = 14, // QVector<QHelpSearchResult >
+    SBK_QTHELP_QLIST_QVARIANT_IDX                            = 15, // QList<QVariant >
+    SBK_QTHELP_QLIST_QSTRING_IDX                             = 16, // QList<QString >
+    SBK_QTHELP_QMAP_QSTRING_QVARIANT_IDX                     = 17, // QMap<QString,QVariant >
+    SBK_QtHelp_CONVERTERS_IDX_COUNT                          = 18
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QHelpSearchResult >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchQuery::FieldName >() { return SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_FIELDNAME_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchQuery >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QHelpContentItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTITEM_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QHelpContentModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTMODEL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpIndexModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXMODEL_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHENGINE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpEngineCore >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPENGINECORE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPENGINE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchResultWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULTWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpSearchQueryWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERYWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QHelpIndexWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXWIDGET_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QHelpContentWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPCONTENTWIDGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPENGINE_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpEngineCore >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPENGINECORE_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpIndexModel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXMODEL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpIndexWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPINDEXWIDGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchEngine >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHENGINE_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchQuery::FieldName >() { return SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_FIELDNAME_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchQuery >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchQueryWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHQUERYWIDGET_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchResult >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULT_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QHelpSearchResultWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtHelpTypes[SBK_QHELPSEARCHRESULTWIDGET_IDX]); }
 
 } // namespace Shiboken
 
